@@ -5,23 +5,22 @@
 # (see spyder/__init__.py for details)
 
 """
-Spyder configuration options
+Spyder configuration options.
 
 Note: Leave this file free of Qt related imports, so that it can be used to
-quickly load a user config file
+quickly load a user config file.
 """
 
 import os
-import os.path as osp
 import sys
 
 # Local import
-from spyder.config.base import (CHECK_ALL, EXCLUDED_NAMES, get_home_dir,
-                                SUBFOLDER)
-from spyder.config.fonts import BIG, MEDIUM, MONOSPACE, SANS_SERIF
-from spyder.config.user import UserConfig
+from spyder.config.base import CHECK_ALL, EXCLUDED_NAMES
+from spyder.config.fonts import MEDIUM, SANS_SERIF
 from spyder.config.utils import IMPORT_EXT
-from spyder.utils import codeanalysis
+from spyder.config.appearance import APPEARANCE
+from spyder.plugins.editor.utils.findtasks import TASKS_PATTERN
+from spyder.utils.introspection.module_completion import PREFERRED_MODULES
 
 
 # =============================================================================
@@ -33,33 +32,25 @@ EXCLUDE_PATTERNS = ['*.csv, *.dat, *.log, *.tmp, *.bak, *.orig']
 # Extensions that should be visible in Spyder's file/project explorers
 SHOW_EXT = ['.py', '.ipynb', '.txt', '.dat', '.pdf', '.png', '.svg']
 
-
 # Extensions supported by Spyder (Editor or Variable explorer)
 USEFUL_EXT = IMPORT_EXT + SHOW_EXT
 
-
 # Name filters for file/project explorers (excluding files without extension)
 NAME_FILTERS = ['README', 'INSTALL', 'LICENSE', 'CHANGELOG'] + \
                ['*' + _ext for _ext in USEFUL_EXT if _ext]
 
-
 # Port used to detect if there is a running instance and to communicate with
 # it to open external files
 OPEN_FILES_PORT = 21128
 
-
 # OS Specific
 WIN = os.name == 'nt'
 MAC = sys.platform == 'darwin'
+LINUX = sys.platform.startswith('linux')
 CTRL = "Meta" if MAC else "Ctrl"
 
-# Run cell shortcuts
-if sys.platform == 'darwin':
-    RUN_CELL_SHORTCUT = 'Meta+Return'
-else:
-    RUN_CELL_SHORTCUT = 'Ctrl+Return'
-RE_RUN_LAST_CELL_SHORTCUT = 'Alt+Return'
-RUN_CELL_AND_ADVANCE_SHORTCUT = 'Shift+Return'
+# Modules to be preloaded for Rope and Jedi
+PRELOAD_MDOULES = ', '.join(PREFERRED_MODULES)
 
 
 # =============================================================================
@@ -68,11 +59,11 @@ RUN_CELL_AND_ADVANCE_SHORTCUT = 'Shift+Return'
 DEFAULTS = [
             ('main',
              {
-              'icon_theme': 'spyder 3',
               'opengl': 'software',
               'single_instance': True,
               'open_files_port': OPEN_FILES_PORT,
               'tear_off_menus': False,
+              'mac_open_file': False,
               'normal_screen_resolution': True,
               'high_dpi_scaling': False,
               'high_dpi_custom_scale_factor': False,
@@ -86,30 +77,22 @@ DEFAULTS = [
               'window/position': (10, 10),
               'window/is_maximized': True,
               'window/is_fullscreen': False,
-              'window/prefs_dialog_size': (745, 411),
+              'window/prefs_dialog_size': (1050, 530),
               'show_status_bar': True,
               'memory_usage/enable': True,
               'memory_usage/timeout': 2000,
               'cpu_usage/enable': False,
               'cpu_usage/timeout': 2000,
+              'clock/enable': False,
+              'clock/timeout': 1000,
               'use_custom_margin': True,
               'custom_margin': 0,
               'use_custom_cursor_blinking': False,
               'show_internal_errors': True,
               'check_updates_on_startup': True,
               'toolbars_visible': True,
-              # Global Spyder fonts
-              'font/family': MONOSPACE,
-              'font/size': MEDIUM,
-              'font/italic': False,
-              'font/bold': False,
-              'rich_font/family': SANS_SERIF,
-              'rich_font/size': BIG,
-              'rich_font/italic': False,
-              'rich_font/bold': False,
               'cursor/width': 2,
               'completion/size': (300, 180),
-              'report_error/remember_me': False,
               'report_error/remember_token': False,
               }),
             ('quick_layouts',
@@ -125,13 +108,9 @@ DEFAULTS = [
               'working_dir_history': 30,
               'working_dir_adjusttocontents': False,
               'wrap': True,
-              'calltips': True,
               'codecompletion/auto': False,
-              'codecompletion/enter_key': True,
-              'codecompletion/case_sensitive': True,
               'external_editor/path': 'SciTE',
               'external_editor/gotoline': '-goto:',
-              'light_background': True,
               }),
             ('main_interpreter',
              {
@@ -185,9 +164,18 @@ DEFAULTS = [
               'exclude_private': True,
               'exclude_uppercase': True,
               'exclude_capitalized': False,
-              'exclude_unsupported': True,
+              'exclude_unsupported': False,
+              'exclude_callables_and_modules': True,
               'truncate': True,
-              'minmax': False
+              'minmax': False,
+              'show_callable_attributes': True,
+              'show_special_attributes': False
+             }),
+            ('plots',
+             {
+              'mute_inline_plotting': True,
+              'show_plot_outline': False,
+              'auto_fit_plotting': True
              }),
             ('editor',
              {
@@ -197,8 +185,6 @@ DEFAULTS = [
               'printer_header/font/bold': False,
               'wrap': False,
               'wrapflag': True,
-              'code_analysis/pyflakes': True,
-              'code_analysis/pep8': False,
               'todo_list': True,
               'realtime_analysis': True,
               'realtime_analysis/timeout': 2500,
@@ -206,32 +192,46 @@ DEFAULTS = [
               'line_numbers': True,
               'blank_spaces': False,
               'edge_line': True,
-              'edge_line_column': 79,
+              'edge_line_columns': '79',
+              'indent_guides': False,
+              'code_folding': True,
+              'show_code_folding_warning': True,
+              'scroll_past_end': False,
               'toolbox_panel': True,
-              'calltips': True,
-              'go_to_definition': True,
               'close_parentheses': True,
-              'close_quotes': False,
+              'close_quotes': True,
               'add_colons': True,
               'auto_unindent': True,
               'indent_chars': '*    *',
               'tab_stop_width_spaces': 4,
-              'codecompletion/auto': True,
-              'codecompletion/enter_key': True,
-              'codecompletion/case_sensitive': True,
               'check_eol_chars': True,
+              'convert_eol_on_save': False,
+              'convert_eol_on_save_to': 'LF',
               'tab_always_indent': False,
               'intelligent_backspace': True,
+              'automatic_completions': True,
+              'automatic_completions_after_chars': 3,
+              'automatic_completions_after_ms': 300,
+              'completions_wait_for_ms': 200,
+              'completions_hint': True,
+              'completions_hint_after_ms': 500,
+              'underline_errors': False,
               'highlight_current_line': True,
               'highlight_current_cell': True,
               'occurrence_highlighting': True,
               'occurrence_highlighting/timeout': 1500,
               'always_remove_trailing_spaces': False,
               'show_tab_bar': True,
+              'show_class_func_dropdown': False,
               'max_recent_files': 20,
               'save_all_before_run': True,
               'focus_to_editor': True,
-              'onsave_analysis': False
+              'run_cell_copy': False,
+              'onsave_analysis': False,
+              'autosave_enabled': True,
+              'autosave_interval': 60,
+              'docstring_type': 'Numpydoc',
+              'strip_trailing_spaces_on_modify': False,
               }),
             ('historylog',
              {
@@ -239,6 +239,7 @@ DEFAULTS = [
               'max_entries': 100,
               'wrap': True,
               'go_to_eof': True,
+              'line_numbers': False,
               }),
             ('help',
              {
@@ -261,6 +262,8 @@ DEFAULTS = [
               'enable': True,
               'show_fullpath': False,
               'show_all_files': False,
+              'group_cells': True,
+              'sort_files_alphabetically': False,
               'show_comments': True,
               }),
             ('project_explorer',
@@ -268,6 +271,7 @@ DEFAULTS = [
               'name_filters': NAME_FILTERS,
               'show_all': True,
               'show_hscrollbar': True,
+              'max_recent_projects': 10,
               'visible_if_project_open': True
               }),
             ('explorer',
@@ -275,9 +279,9 @@ DEFAULTS = [
               'enable': True,
               'wrap': True,
               'name_filters': NAME_FILTERS,
-              'show_hidden': True,
+              'show_hidden': False,
               'show_all': True,
-              'show_icontext': False,
+              'single_click_to_open': False,
               }),
             ('find_in_files',
              {
@@ -287,9 +291,23 @@ DEFAULTS = [
               'exclude_regexp': False,
               'search_text_regexp': False,
               'search_text': [''],
-              'search_text_samples': [codeanalysis.TASKS_PATTERN],
-              'more_options': True,
-              'case_sensitive': False
+              'search_text_samples': [TASKS_PATTERN],
+              'more_options': False,
+              'case_sensitive': False,
+              'max_results': 1000,
+              }),
+            ('breakpoints',
+             {
+              'enable': True,
+              }),
+            ('profiler',
+             {
+              'enable': True,
+              }),
+            ('pylint',
+             {
+              'enable': True,
+              'max_entries': 30,
               }),
             ('workingdir',
              {
@@ -298,6 +316,7 @@ DEFAULTS = [
               'console/use_project_or_home_directory': False,
               'console/use_cwd': True,
               'console/use_fixed_directory': False,
+              'startup/use_fixed_directory': False,
               }),
             ('shortcuts',
              {
@@ -339,19 +358,20 @@ DEFAULTS = [
               '_/switch to variable_explorer': "Ctrl+Shift+V",
               '_/switch to find_in_files': "Ctrl+Shift+F",
               '_/switch to explorer': "Ctrl+Shift+X",
+              '_/switch to plots': "Ctrl+Shift+G",
               # -- In widgets/findreplace.py
-              '_/find text': "Ctrl+F",
-              '_/find next': "F3",
-              '_/find previous': "Shift+F3",
-              '_/replace text': "Ctrl+R",
-              '_/hide find and replace': "Escape",
+              'find_replace/find text': "Ctrl+F",
+              'find_replace/find next': "F3",
+              'find_replace/find previous': "Shift+F3",
+              'find_replace/replace text': "Ctrl+R",
+              'find_replace/hide find and replace': "Escape",
               # ---- Editor ----
               # -- In widgets/sourcecode/codeeditor.py
               'editor/code completion': CTRL+'+Space',
-              'editor/duplicate line': "Ctrl+Alt+Up" if WIN else \
-                                       "Shift+Alt+Up",
-              'editor/copy line': "Ctrl+Alt+Down" if WIN else \
-                                  "Shift+Alt+Down",
+              'editor/duplicate line up': (
+                  "Ctrl+Alt+Up" if WIN else "Shift+Alt+Up"),
+              'editor/duplicate line down': (
+                  "Ctrl+Alt+Down" if WIN else "Shift+Alt+Down"),
               'editor/delete line': 'Ctrl+D',
               'editor/transform to uppercase': 'Ctrl+Shift+U',
               'editor/transform to lowercase': 'Ctrl+U',
@@ -370,8 +390,8 @@ DEFAULTS = [
               'editor/next line': "Meta+N",
               'editor/previous char': "Meta+B",
               'editor/next char': "Meta+F",
-              'editor/previous word': "Meta+Left",
-              'editor/next word': "Meta+Right",
+              'editor/previous word': "Ctrl+Left",
+              'editor/next word': "Ctrl+Right",
               'editor/kill to line end': "Meta+K",
               'editor/kill to line start': "Meta+U",
               'editor/yank': 'Meta+Y',
@@ -385,7 +405,7 @@ DEFAULTS = [
               'editor/cut': 'Ctrl+X',
               'editor/copy': 'Ctrl+C',
               'editor/paste': 'Ctrl+V',
-              'editor/delete': 'Delete',
+              'editor/delete': 'Del',
               'editor/select all': "Ctrl+A",
               # -- In widgets/editor.py
               'editor/inspect current object': 'Ctrl+I',
@@ -393,8 +413,8 @@ DEFAULTS = [
               'editor/conditional breakpoint': 'Shift+F12',
               'editor/run selection': "F9",
               'editor/go to line': 'Ctrl+L',
-              'editor/go to previous file': 'Ctrl+Shift+Tab',
-              'editor/go to next file': 'Ctrl+Tab',
+              'editor/go to previous file': CTRL + '+Shift+Tab',
+              'editor/go to next file': CTRL + '+Tab',
               'editor/cycle to previous file': 'Ctrl+PgUp',
               'editor/cycle to next file': 'Ctrl+PgDown',
               'editor/new file': "Ctrl+N",
@@ -405,19 +425,27 @@ DEFAULTS = [
               'editor/save as': 'Ctrl+Shift+S',
               'editor/close all': "Ctrl+Shift+W",
               'editor/last edit location': "Ctrl+Alt+Shift+Left",
-              'editor/previous cursor position': "Ctrl+Alt+Left",
-              'editor/next cursor position': "Ctrl+Alt+Right",
+              'editor/previous cursor position': "Alt+Left",
+              'editor/next cursor position': "Alt+Right",
+              'editor/previous warning': "Ctrl+Alt+Shift+,",
+              'editor/next warning': "Ctrl+Alt+Shift+.",
               'editor/zoom in 1': "Ctrl++",
               'editor/zoom in 2': "Ctrl+=",
               'editor/zoom out': "Ctrl+-",
               'editor/zoom reset': "Ctrl+0",
               'editor/close file 1': "Ctrl+W",
               'editor/close file 2': "Ctrl+F4",
-              'editor/run cell': RUN_CELL_SHORTCUT,
-              'editor/run cell and advance': RUN_CELL_AND_ADVANCE_SHORTCUT,
+              'editor/run cell': CTRL + '+Return',
+              'editor/run cell and advance': 'Shift+Return',
+              'editor/debug cell': 'Alt+Shift+Return',
               'editor/go to next cell': 'Ctrl+Down',
               'editor/go to previous cell': 'Ctrl+Up',
-              'editor/re-run last cell': RE_RUN_LAST_CELL_SHORTCUT,
+              'editor/re-run last cell': 'Alt+Return',
+              'editor/split vertically': "Ctrl+{",
+              'editor/split horizontally': "Ctrl+_",
+              'editor/close split panel': "Alt+Shift+W",
+              'editor/docstring': "Ctrl+Alt+D",
+              'editor/show in external file explorer': '',
               # -- In Breakpoints
               '_/switch to breakpoints': "Ctrl+Shift+B",
               # ---- Consoles (in widgets/shell) ----
@@ -435,209 +463,163 @@ DEFAULTS = [
               # ---- In widgets/arraybuider.py ----
               'array_builder/enter array inline': "Ctrl+Alt+M",
               'array_builder/enter array table': "Ctrl+M",
-              # ---- In widgets/variableexplorer/aarayeditor.py ----
+              # ---- In widgets/variableexplorer/arrayeditor.py ----
               'variable_explorer/copy': 'Ctrl+C',
+              # ---- In widgets/variableexplorer/namespacebrowser.py ----
+              'variable_explorer/search': 'Ctrl+F',
+              'variable_explorer/refresh': 'Ctrl+R',
+              # ---- In widgets/plots/figurebrowser.py ----
+              'plots/copy': 'Ctrl+C',
+              'plots/previous figure': 'Ctrl+PgUp',
+              'plots/next figure': 'Ctrl+PgDown',
+              'plots/save': 'Ctrl+S',
+              'plots/save all': 'Ctrl+Alt+S',
+              'plots/close': 'Ctrl+W',
+              'plots/close all': 'Ctrl+Shift+W',
+              'plots/zoom in': "Ctrl++",
+              'plots/zoom out': "Ctrl+-",
+              # ---- In widgets/explorer ----
+              'explorer/copy file': 'Ctrl+C',
+              'explorer/paste file': 'Ctrl+V',
+              'explorer/copy absolute path': 'Ctrl+Alt+C',
+              'explorer/copy relative path': 'Ctrl+Alt+Shift+C',
               }),
-            ('color_schemes',
+            ('appearance', APPEARANCE),
+            ('lsp-server',
              {
-              'names': ['emacs', 'idle', 'monokai', 'pydev', 'scintilla',
-                        'spyder', 'spyder/dark', 'zenburn', 'solarized/light',
-                        'solarized/dark'],
-              'selected': 'spyder',
-              # ---- Emacs ----
-              'emacs/name':        "Emacs",
-              #      Name            Color     Bold  Italic
-              'emacs/background':  "#000000",
-              'emacs/currentline': "#2b2b43",
-              'emacs/currentcell': "#1c1c2d",
-              'emacs/occurrence':   "#abab67",
-              'emacs/ctrlclick':   "#0000ff",
-              'emacs/sideareas':   "#555555",
-              'emacs/matched_p':   "#009800",
-              'emacs/unmatched_p': "#c80000",
-              'emacs/normal':     ('#ffffff', False, False),
-              'emacs/keyword':    ('#3c51e8', False, False),
-              'emacs/builtin':    ('#900090', False, False),
-              'emacs/definition': ('#ff8040', True, False),
-              'emacs/comment':    ('#005100', False, False),
-              'emacs/string':     ('#00aa00', False, True),
-              'emacs/number':     ('#800000', False, False),
-              'emacs/instance':   ('#ffffff', False, True),
-              # ---- IDLE ----
-              'idle/name':         "IDLE",
-              #      Name            Color     Bold  Italic
-              'idle/background':   "#ffffff",
-              'idle/currentline':  "#f2e6f3",
-              'idle/currentcell':  "#feefff",
-              'idle/occurrence':    "#e8f2fe",
-              'idle/ctrlclick':    "#0000ff",
-              'idle/sideareas':    "#efefef",
-              'idle/matched_p':    "#99ff99",
-              'idle/unmatched_p':  "#ff9999",
-              'idle/normal':      ('#000000', False, False),
-              'idle/keyword':     ('#ff7700', True, False),
-              'idle/builtin':     ('#900090', False, False),
-              'idle/definition':  ('#0000ff', False, False),
-              'idle/comment':     ('#dd0000', False, True),
-              'idle/string':      ('#00aa00', False, False),
-              'idle/number':      ('#924900', False, False),
-              'idle/instance':    ('#777777', True, True),
-              # ---- Monokai ----
-              'monokai/name':         "Monokai",
-              #      Name              Color     Bold  Italic
-              'monokai/background':   "#2a2b24",
-              'monokai/currentline':  "#484848",
-              'monokai/currentcell':  "#3d3d3d",
-              'monokai/occurrence':    "#666666",
-              'monokai/ctrlclick':    "#0000ff",
-              'monokai/sideareas':    "#2a2b24",
-              'monokai/matched_p':    "#688060",
-              'monokai/unmatched_p':  "#bd6e76",
-              'monokai/normal':      ("#ddddda", False, False),
-              'monokai/keyword':     ("#f92672", False, False),
-              'monokai/builtin':     ("#ae81ff", False, False),
-              'monokai/definition':  ("#a6e22e", False, False),
-              'monokai/comment':     ("#75715e", False, True),
-              'monokai/string':      ("#e6db74", False, False),
-              'monokai/number':      ("#ae81ff", False, False),
-              'monokai/instance':    ("#ddddda", False, True),
-              # ---- Pydev ----
-              'pydev/name':        "Pydev",
-              #      Name            Color     Bold  Italic
-              'pydev/background':  "#ffffff",
-              'pydev/currentline': "#e8f2fe",
-              'pydev/currentcell': "#eff8fe",
-              'pydev/occurrence':   "#ffff99",
-              'pydev/ctrlclick':   "#0000ff",
-              'pydev/sideareas':   "#efefef",
-              'pydev/matched_p':   "#99ff99",
-              'pydev/unmatched_p': "#ff99992",
-              'pydev/normal':     ('#000000', False, False),
-              'pydev/keyword':    ('#0000ff', False, False),
-              'pydev/builtin':    ('#900090', False, False),
-              'pydev/definition': ('#000000', True, False),
-              'pydev/comment':    ('#c0c0c0', False, False),
-              'pydev/string':     ('#00aa00', False, True),
-              'pydev/number':     ('#800000', False, False),
-              'pydev/instance':   ('#000000', False, True),
-              # ---- Scintilla ----
-              'scintilla/name':        "Scintilla",
-              #         Name             Color     Bold  Italic
-              'scintilla/background':  "#ffffff",
-              'scintilla/currentline': "#e1f0d1",
-              'scintilla/currentcell': "#edfcdc",
-              'scintilla/occurrence':   "#ffff99",
-              'scintilla/ctrlclick':   "#0000ff",
-              'scintilla/sideareas':   "#efefef",
-              'scintilla/matched_p':   "#99ff99",
-              'scintilla/unmatched_p': "#ff9999",
-              'scintilla/normal':     ('#000000', False, False),
-              'scintilla/keyword':    ('#00007f', True, False),
-              'scintilla/builtin':    ('#000000', False, False),
-              'scintilla/definition': ('#007f7f', True, False),
-              'scintilla/comment':    ('#007f00', False, False),
-              'scintilla/string':     ('#7f007f', False, False),
-              'scintilla/number':     ('#007f7f', False, False),
-              'scintilla/instance':   ('#000000', False, True),
-              # ---- Spyder ----
-              'spyder/name':        "Spyder",
-              #       Name            Color     Bold  Italic
-              'spyder/background':  "#ffffff",
-              'spyder/currentline': "#f7ecf8",
-              'spyder/currentcell': "#fdfdde",
-              'spyder/occurrence':   "#ffff99",
-              'spyder/ctrlclick':   "#0000ff",
-              'spyder/sideareas':   "#efefef",
-              'spyder/matched_p':   "#99ff99",
-              'spyder/unmatched_p': "#ff9999",
-              'spyder/normal':     ('#000000', False, False),
-              'spyder/keyword':    ('#0000ff', False, False),
-              'spyder/builtin':    ('#900090', False, False),
-              'spyder/definition': ('#000000', True, False),
-              'spyder/comment':    ('#adadad', False, True),
-              'spyder/string':     ('#00aa00', False, False),
-              'spyder/number':     ('#800000', False, False),
-              'spyder/instance':   ('#924900', False, True),
-              # ---- Spyder/Dark ----
-              'spyder/dark/name':        "Spyder Dark",
-              #           Name             Color     Bold  Italic
-              'spyder/dark/background':  "#131926",
-              'spyder/dark/currentline': "#2b2b43",
-              'spyder/dark/currentcell': "#31314e",
-              'spyder/dark/occurrence':   "#abab67",
-              'spyder/dark/ctrlclick':   "#0000ff",
-              'spyder/dark/sideareas':   "#282828",
-              'spyder/dark/matched_p':   "#009800",
-              'spyder/dark/unmatched_p': "#c80000",
-              'spyder/dark/normal':     ('#ffffff', False, False),
-              'spyder/dark/keyword':    ('#558eff', False, False),
-              'spyder/dark/builtin':    ('#aa00aa', False, False),
-              'spyder/dark/definition': ('#ffffff', True, False),
-              'spyder/dark/comment':    ('#7f7f7f', False, False),
-              'spyder/dark/string':     ('#11a642', False, True),
-              'spyder/dark/number':     ('#c80000', False, False),
-              'spyder/dark/instance':   ('#be5f00', False, True),
-              # ---- Zenburn ----
-              'zenburn/name':        "Zenburn",
-              #        Name            Color     Bold  Italic
-              'zenburn/background':  "#3f3f3f",
-              'zenburn/currentline': "#333333",
-              'zenburn/currentcell': "#2c2c2c",
-              'zenburn/occurrence':   "#7a738f",
-              'zenburn/ctrlclick':   "#0000ff",
-              'zenburn/sideareas':   "#3f3f3f",
-              'zenburn/matched_p':   "#688060",
-              'zenburn/unmatched_p': "#bd6e76",
-              'zenburn/normal':     ('#dcdccc', False, False),
-              'zenburn/keyword':    ('#dfaf8f', True, False),
-              'zenburn/builtin':    ('#efef8f', False, False),
-              'zenburn/definition': ('#efef8f', False, False),
-              'zenburn/comment':    ('#7f9f7f', False, True),
-              'zenburn/string':     ('#cc9393', False, False),
-              'zenburn/number':     ('#8cd0d3', False, False),
-              'zenburn/instance':   ('#dcdccc', False, True),
-              # ---- Solarized Light ----
-              'solarized/light/name':        "Solarized Light",
-              #        Name            Color     Bold  Italic
-              'solarized/light/background':  '#fdf6e3',
-              'solarized/light/currentline': '#f5efdB',
-              'solarized/light/currentcell': '#eee8d5',
-              'solarized/light/occurrence':   '#839496',
-              'solarized/light/ctrlclick':   '#d33682',
-              'solarized/light/sideareas':   '#eee8d5',
-              'solarized/light/matched_p':   '#586e75',
-              'solarized/light/unmatched_p': '#dc322f',
-              'solarized/light/normal':     ('#657b83', False, False),
-              'solarized/light/keyword':    ('#859900', False, False),
-              'solarized/light/builtin':    ('#6c71c4', False, False),
-              'solarized/light/definition': ('#268bd2', True, False),
-              'solarized/light/comment':    ('#93a1a1', False, True),
-              'solarized/light/string':     ('#2aa198', False, False),
-              'solarized/light/number':     ('#cb4b16', False, False),
-              'solarized/light/instance':   ('#b58900', False, True),
-              # ---- Solarized Dark ----
-              'solarized/dark/name':        "Solarized Dark",
-              #        Name            Color     Bold  Italic
-              'solarized/dark/background':  '#002b36',
-              'solarized/dark/currentline': '#083f4d',
-              'solarized/dark/currentcell': '#073642',
-              'solarized/dark/occurrence':   '#657b83',
-              'solarized/dark/ctrlclick':   '#d33682',
-              'solarized/dark/sideareas':   '#073642',
-              'solarized/dark/matched_p':   '#93a1a1',
-              'solarized/dark/unmatched_p': '#dc322f',
-              'solarized/dark/normal':     ('#839496', False, False),
-              'solarized/dark/keyword':    ('#859900', False, False),
-              'solarized/dark/builtin':    ('#6c71c4', False, False),
-              'solarized/dark/definition': ('#268bd2', True, False),
-              'solarized/dark/comment':    ('#586e75', False, True),
-              'solarized/dark/string':     ('#2aa198', False, False),
-              'solarized/dark/number':     ('#cb4b16', False, False),
-              'solarized/dark/instance':   ('#b58900', False, True)
-             })
+              # This option is not used with the LSP server config
+              # It is used to disable hover hints in the editor
+              'enable_hover_hints': True,
+              'show_lsp_down_warning': True,
+              'code_completion': True,
+              'code_snippets': True,
+              'jedi_definition': True,
+              'jedi_definition/follow_imports': True,
+              'jedi_signature_help': True,
+              'preload_modules': PRELOAD_MDOULES,
+              'pyflakes': True,
+              'mccabe': False,
+              'pycodestyle': False,
+              'pycodestyle/filename': '',
+              'pycodestyle/exclude': '',
+              'pycodestyle/select': '',
+              'pycodestyle/ignore': '',
+              'pycodestyle/max_line_length': 79,
+              'pydocstyle': False,
+              'pydocstyle/convention': 'numpy',
+              'pydocstyle/select': '',
+              'pydocstyle/ignore': '',
+              'pydocstyle/match': '(?!test_).*\\.py',
+              'pydocstyle/match_dir': '[^\\.].*',
+              'advanced/enabled': False,
+              'advanced/module': 'pyls',
+              'advanced/host': '127.0.0.1',
+              'advanced/port': 2087,
+              'advanced/external': False,
+              'advanced/stdio': False
+             }),
+            ('fallback-completions',
+             {
+              'enable': True,
+             }),
+            ('kite',
+             {
+              'enable': True,
+              'call_to_action': True,
+              # Enable the installation dialog
+              'show_installation_dialog': True,
+              'show_onboarding': True,
+              'show_installation_error_message': True,
+             }),
             ]
 
 
+NAME_MAP = {
+    # Empty container object means use the rest of defaults
+    'spyder': [],
+    # Splitting these files makes sense for projects, we might as well
+    # apply the same split for the app global config
+    # These options change on spyder startup or are tied to a specific OS,
+    # not good for version control
+    'transient': [
+        ('main', [
+            'completion/size',
+            'crash',
+            'current_version',
+            'historylog_filename',
+            'last_visible_toolbars',
+            'spyder_pythonpath',
+            'window/position',
+            'window/prefs_dialog_size',
+            'window/size',
+            'window/state',
+            ]
+         ),
+        ('appearance', [
+            'windows_style',
+            ]
+         ),
+        ('editor', [
+            'autosave_mapping',
+            'bookmarks',
+            'filenames',
+            'layout_settings',
+            'recent_files',
+            'splitter_state',
+            ]
+         ),
+        ('explorer', [
+            'file_associations',
+        ]),
+        ('find_in_files', [
+            'path_history'
+            'search_text',
+            ]
+         ),
+        ('main_interpreter', [
+            'custom_interpreters_list',
+            'custom_interpreter',
+            'executable',
+             ]
+         ),
+        ('onlinehelp', [
+            'zoom_factor',
+             ]
+         ),
+        ('outline_explorer', [
+            'expanded_state',
+            'scrollbar_position',
+            ],
+         ),
+        ('project_explorer', [
+            'current_project_path',
+            'expanded_state',
+            'recent_projects',
+            'max_recent_projects',
+            'scrollbar_position',
+          ]
+         ),
+        ('quick_layouts', []), # Empty list means use all options
+        ('run', [
+            'breakpoints',
+            'configurations',
+            'defaultconfiguration',
+            'default/wdir/fixed_directory',
+          ]
+         ),
+        ('workingdir', [
+            'console/fixed_directory',
+            'startup/fixed_directory',
+          ]
+         ),
+        ('pylint', [
+          'history_filenames',
+          ]
+         ),
+    ]
+}
+
+
 # =============================================================================
 # Config instance
 # =============================================================================
@@ -648,19 +630,4 @@ DEFAULTS = [
 #    or if you want to *rename* options, then you need to do a MAJOR update in
 #    version, e.g. from 3.0.0 to 4.0.0
 # 3. You don't need to touch this value if you're just adding a new option
-CONF_VERSION = '46.2.0'
-
-# Main configuration instance
-try:
-    CONF = UserConfig('spyder', defaults=DEFAULTS, load=True,
-                      version=CONF_VERSION, subfolder=SUBFOLDER, backup=True,
-                      raw_mode=True)
-except Exception:
-    CONF = UserConfig('spyder', defaults=DEFAULTS, load=False,
-                      version=CONF_VERSION, subfolder=SUBFOLDER, backup=True,
-                      raw_mode=True)
-
-# Removing old .spyder.ini location:
-old_location = osp.join(get_home_dir(), '.spyder.ini')
-if osp.isfile(old_location):
-    os.remove(old_location)
+CONF_VERSION = '58.0.0'
